==> banshee-1-1.4.3.tar.bz2: banshee-1-1.4.3/src/Core/Banshee.Services/Banshee.Library/ImportSourceManager.cs <==
// 
// ImportSourceManager.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections;
using System.Collections.Generic;
using Mono.Addins;

using Banshee.PlayerMigration;
using Banshee.ServiceStack;

namespace Banshee.Library
{
    public class ImportSourceManager : IService, IEnumerable<IImportSource>
    {
        private List<IImportSource> import_sources;
        
        public ImportSourceManager ()
        {
        }
        
        public IEnumerator<IImportSource> GetEnumerator ()
        {
            if (import_sources == null) {
                import_sources = new List<IImportSource> ();
                import_sources.Add (new HomeDirectoryImportSource ());
                
                if (AmarokPlayerImportSource.CanImport) {
                    import_sources.Add (new AmarokPlayerImportSource ());
                }
            
                foreach (IImportSource source in AddinManager.GetExtensionObjects ("/Banshee/Library/ImportSource")) {
                    if (source.CanImport) {
                        import_sources.Add (source);
                    }
                }
            }
            
            return import_sources.GetEnumerator ();
        }
        
        IEnumerator IEnumerable.GetEnumerator ()
        {
            return GetEnumerator ();
        }
        
        string IService.ServiceName {
            get { return "ImportSourceManager"; }
        }
    }
}

==> banshee-1-1.5.4.tar.bz2: banshee-1-1.5.4/src/Core/Banshee.Services/Banshee.Library/ImportSourceManager.cs <==
//
// ImportSourceManager.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections;
using System.Collections.Generic;
using Mono.Addins;

using Banshee.ServiceStack;

namespace Banshee.Library
{
    public class ImportSourceManager : IService, IEnumerable<IImportSource>
    {
        private HomeDirectoryImportSource home_source = new HomeDirectoryImportSource ();

        public ImportSourceManager ()
        {
        }

        public IEnumerator<IImportSource> GetEnumerator ()
        {
            List<IImportSource> import_sources = new List<IImportSource> ();
            import_sources.Add (home_source);

            foreach (IImportSource source in AddinManager.GetExtensionObjects ("/Banshee/Library/ImportSource")) {
                if (source.CanImport) {
                    import_sources.Add (source);
                }
            }

            return import_sources.GetEnumerator ();
        }

        IEnumerator IEnumerable.GetEnumerator ()
        {
            return GetEnumerator ();
        }

        string IService.ServiceName {
            get { return "ImportSourceManager"; }
        }
    }
}
